##  Additional Resources
To learn more about SBOMs and explore available tools, refer to:
  * [awesome-sbom![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2FawesomeSBOM%2Fawesome-sbom "https://github.com/awesomeSBOM/awesome-sbom"), providing a curated list of SBOM-related tools, frameworks, blogs, podcasts, and articles
  * [SBOM Resources Library![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.cisa.gov%2Ftopics%2Fcyber-threats-and-advisories%2Fsbom%2Fsbomresourceslibrary "https://www.cisa.gov/topics/cyber-threats-and-advisories/sbom/sbomresourceslibrary") from the Cybersecurity and Infrastructure Security Agency (CISA)
  * [CycloneDX![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcyclonedx.org%2F "https://cyclonedx.org/")
  * [SPDX![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fspdx.dev%2F "https://spdx.dev/")
